# Parameter file for simulating a one component cylindrical vesicle
# at fixed box size and temperature.
#
#
# To run this file use $ESPRESSO_SOURCE/Espresso_bin ../scripts/main.tcl cylinder.tcl
#
# For more information about the simulation model on which this
# simulation is based see the following reference
# 
#  Cooke, I. R., Kremer, K. and Deserno, M.(2005): Tuneable, generic
# model for fluid bilayer membranes. Phys. Rev. E. 72 - 011506 
#

puts " "
puts "============================================================="
puts " Parameter Script for the Simulation of a Cylindrical Vesicle"
puts "============================================================="

::mmsg::send [namespace current] "loading parameter file .. " nonewline
flush stdout

# specify L_z
set L_z 20


# Specify the name of the job <ident> the location of forcetables and
# the output and scripts directories
set ident "cylinder$L_z"
set tabledir "./forcetables/"
set outputdir "./$ident"
set topofile "$ident.top"

# Specify how we want to use vmd for visualization allowable values
# are "interactive" "offline" "none".  interactive rarely works
set use_vmd "offline"
lappend vmdcommands "mol modcolor 0 0 segname"
lappend vmdcommands "mol modstyle 0 0 licorice 0.2 20 20"


# --- Specify a global key for molecule types -----#

# Here we specify the details of all molecule types in the
# system.  In this example molecule type 0 is assigned to be a lipid.
# The atom types in this lipid are 0 and 1 respectively and the
# bonding interactions are type 0 for short bonds and type 1 for long
# bonds.
set moltypes [list { 0 lipid { 0 1 2 } { 0 1 } } ]

# --- Specify the system geometry and composition ----#
set geometry { geometry "cylinder -shuffle" }

# Use 1000 lipids (molecules of type 0 ) for the cylinder
set n_molslist { n_molslist {  { 0 1000 } } }

# Now bundle the above info into a list
lappend cylindrspec $geometry
lappend cylindrspec $n_molslist


# Now group the bilayerspec with other specs into a list of such
# systems (we can have multiple systems if we like each with different
# composition of molecule types
lappend system_specs $cylindrspec


# Specify the system  size
set box_l 40
set setbox_l  " 40.0 40.0 $L_z "
lappend vmdcommands "pbc set \{ 40.0 40.0 $L_z\} -all"
lappend vmdcommands "pbc box"

setmd max_num_cells 4000



# Warmup parameters
#----------------------------------------------------------#
set warm_time_step 0.002
set free_warmsteps 0
set free_warmtimes 1

# ------ Integration parameters -----------------#
set main_time_step 0.002
set verlet_skin 0.4
set systemtemp 1.1
# NVT parameters
set thermo "Langevin"		;# "Langevin" or "DPD"
set langevin_gamma 1.0		;# Langevin thermostat parameter

# The number of steps to integrate with each call to integrate
set int_steps   1000
# The number of times to call integrate
set int_n_times 100
# Total Integration time (in tau)
set total_int_time [expr $main_time_step*$int_n_times*$int_steps ]
puts "Total Integration Time: $total_int_time"
# Write a configuration file every <write_frequency> calls
set write_frequency 1
# Write results to analysis files every <analysis_write_frequency> calls
set analysis_write_frequency 1

# Bonded and bending Potentials
#----------------------------------------------------------#
lappend bonded_parms [list 0 FENE 30 1.5 ]
lappend bonded_parms [list 1 harmonic 10.0 4.0 ]

# Non Bonded Potentials
#----------------------------------------------------------#
# Define the forcetables to be used for the interaction of each pair of atom types
# Useful Parameters
set lj_eps 1.0
set lj_cutoff 2.5
set ljshift 0.0
set ljoffset 0.0
set lj_sigmah 0.95
set lj_sigma 1.0

# Define the interaction matrix
lappend nb_interactions [list 0 0 lennard-jones $lj_eps $lj_sigmah [expr 1.1225*$lj_sigmah] [expr 0.25*$lj_eps] $ljoffset ]
lappend nb_interactions [list 0 1 lennard-jones $lj_eps $lj_sigmah [expr 1.1225*$lj_sigmah] [expr 0.25*$lj_eps] $ljoffset ]
lappend nb_interactions [list 0 2 lennard-jones $lj_eps $lj_sigmah [expr 1.1225*$lj_sigmah] [expr 0.25*$lj_eps] $ljoffset ]

# We use a special type of cosine attractive potential for the tail tail interactions. 
lappend nb_interactions [list 1 1 lj-cos2 $lj_eps $lj_sigma $ljoffset 1.6 ]
lappend nb_interactions [list 1 2 lj-cos2 $lj_eps $lj_sigma $ljoffset 1.6 ]
lappend nb_interactions [list 2 2 lj-cos2 $lj_eps $lj_sigma $ljoffset 1.6 ]


# Analysis Parameters
#----------------------------------------------------------#


# Use these flags to specify which observables to calculate during the
# simulation.  Values are calculated after every call to the espresso
# integrate command and written to files like
# time_vs_parametername. See the module ::std_analysis for more
# details
#lappend analysis_flags boxl	       ;# calculate box length
lappend analysis_flags energy 	       ;# calculate energy
#lappend analysis_flags pressure	       ;# pressure calculation
lappend analysis_flags stress_tensor   ;# stress tensor calculation
lappend analysis_flags cylinder_radius ;# cylinder radius calculation
#lappend analysis_flags cluster	       ;# analyzing "clusters"


::mmsg::send [namespace current] "done"
