# Parameter file for simulating a one component random fluid lipid.
# Self-aggregation procedure using the DPD thermostat.
#
#
# To run this file use Espresso_bin ../scripts/main.tcl self_assembly.tcl
#

# For more information about the simulation model on which this
# simulation is based see the following reference
# 
#  Cooke, I. R., Kremer, K. and Deserno, M.(2005): Tuneable, generic
# model for fluid bilayer membranes. Phys. Rev. E. 72 - 011506 
#

puts " "
puts "============================================================"
puts " Parameter Script for the Simulation of a Random Lipid System"
puts "============================================================"

::mmsg::send [namespace current] "loading parameter file .. " nonewline
flush stdout

# Specify the name of the job <ident> the location of forcetables and
# the output and scripts directories
#----------------------------------------------------------#
set ident "self_assembly320"
set tabledir "./forcetables/"
set outputdir "./$ident/"
set topofile "$ident.top"

# Specify how we want to use vmd for visualization allowable values
# are "interactive" "offline" "none".  interactive rarely works
#----------------------------------------------------------#
set use_vmd "offline"
lappend vmdcommands "mol modcolor 0 0 segname"
lappend vmdcommands "mol modstyle 0 0 licorice 0.2 20 20"

# Specify a global key for molecule types 
#----------------------------------------------------------#
set moltypes [list { 0 lipid { 0 1 2 } { 0 1 } } ]

# Specify the system geometry and composition 
#----------------------------------------------------------#
set geometry { geometry random }

# Set number of molecjules of each type
set n_lipid 320
set n_molslist [subst { n_molslist {  { 0 $n_lipid } } }]

# Now bundle the above info into a list
lappend bilayerspec $geometry
lappend bilayerspec $n_molslist

# Now group the bilayerspec with other specs into a list of such
# systems (we can have multiple systems if we like each with different
# composition of molecule types
lappend system_specs $bilayerspec

# Specify the system  size
#----------------------------------------------------------#
set box_l 14.0
set setbox_l [subst { $box_l $box_l $box_l }]
# More accurately, since the final state is supposed to be a lipid bilayer, whose
# area per lipid is about 1.2 sigma^2/lipid, for a MONOLAYER.
# So for a bilayer,  we need a box of area 
#   Area = 0.5*(# of lipids)*1.2(sigma^2/lipid)
# Thus, box length is
#   box_l = sqrt(Area)
#set area [expr 0.5* $n_lipid * 1.2]
#set box_l [expr sqrt($area)]
#set setbox_l [subst { $box_l $box_l $box_l }]

# Some lines for vmd periodic boundary conditions
lappend vmdcommands "pbc set \{ $box_l $box_l $box_l \} -all"
lappend vmdcommands "pbc box"

# MD parameters
#----------------------------------------------------------#
# Warmup parameters
set warm_time_step 0.002
set free_warmsteps 0
set free_warmtimes 1

# ---------------- Integration parameters -----------------#
set main_time_step 0.01
set verlet_skin 0.4
set systemtemp 1.1
# NVT parameters
#set thermo "Langevin"		;# "Langevin" or "DPD"
set thermo "DPD"		;# "Langevin" or "DPD"
set langevin_gamma 1.0		;# Langevin thermostat parameter
set dpd_gamma 1.0		;# DPD thermostat parameter "gamma"
set dpd_r_cut [expr 1.12 + 1.8]	;# D_Rc should be > Rc + wc

# The number of steps to integrate with each call to integrate
set int_steps   200
# The number of times to call integrate
set int_n_times 1000
# Total Integration time (in taus)
set total_int_time [expr $main_time_step*$int_n_times*$int_steps ]
puts "Total Integration Time: $total_int_time"
# Write a configuration file every <write_frequency> calls
set write_frequency 10
# Write results to analysis files every <analysis_write_frequency> calls
set analysis_write_frequency 1

# Bonded and bending Potentials
#----------------------------------------------------------#
lappend bonded_parms [list 0 FENE 30 1.5 ]
lappend bonded_parms [list 1 harmonic 10.0 4.0 ]

# Non Bonded Potentials 
#----------------------------------------------------------#
# Define the interactions between lipid heads and tails
# Useful Parameters
set lj_eps 1.0
set lj_cutoff 2.5
set ljshift 0.0
set ljoffset 0.0
set lj_sigmah 0.95
set lj_sigma 1.0

# Define the interaction matrix
lappend nb_interactions [list 0 0 lennard-jones $lj_eps $lj_sigmah [expr 1.1225*$lj_sigmah] [expr 0.25*$lj_eps] $ljoffset ]
lappend nb_interactions [list 0 1 lennard-jones $lj_eps $lj_sigmah [expr 1.1225*$lj_sigmah] [expr 0.25*$lj_eps] $ljoffset ]
lappend nb_interactions [list 0 2 lennard-jones $lj_eps $lj_sigmah [expr 1.1225*$lj_sigmah] [expr 0.25*$lj_eps] $ljoffset ]

# We use a special type of cosine attractive potential for the tail tail interactions. 
lappend nb_interactions [list 1 1 lj-cos2 $lj_eps $lj_sigma $ljoffset 1.6 ]
lappend nb_interactions [list 1 2 lj-cos2 $lj_eps $lj_sigma $ljoffset 1.6 ]
lappend nb_interactions [list 2 2 lj-cos2 $lj_eps $lj_sigma $ljoffset 1.6 ]

# Analysis Parameters
#----------------------------------------------------------# 

# These are are parameters that will be passed to the setup_analysis
# command when it is called in the main.tcl script.

set mgrid 8
set stray_cut_off 3

# Use these flags to specify which observables to calculate during the
# simulation.  Values are calculated after every call to the espresso
# integrate command and written to files like
# time_vs_parametername. See the analysis package for more
# details
#lappend analysis_flags orient_order
#lappend analysis_flags pressure 
#lappend analysis_flags stress_tensor 
#lappend analysis_flags boxl
#lappend analysis_flags flipflop
lappend analysis_flags energy
#lappend analysis_flags stray
#lappend analysis_flags fluctuations
#set profile_beadtypes [list  0 1 2 ]
#lappend analysis_flags "density_profile -beadtypes \{ $profile_beadtypes \} -nogrid"

::mmsg::send [namespace current] "done"


